@@ -24,7 +24,9 @@ from .qtplugin_base import (WidgetCategory, get_widgets_from_entrypoints,
                             qtplugin_factory)
 from .qtplugin_extensions import (ArchiveTimeCurveEditorExtension,
                                   BasicSettingsExtension, RulesExtension,
-                                  ScatterCurveEditorExtension, SymbolExtension,
+                                  ScatterCurveEditorExtension, 
+                                  EventCurveEditorExtension,
+                                  SymbolExtension,
                                   TimeCurveEditorExtension,
                                   WaveformCurveEditorExtension)
 from .related_display_button import PyDMRelatedDisplayButton
@@ -41,6 +43,7 @@ from .timeplot import PyDMTimePlot
 from .archiver_time_plot import PyDMArchiverTimePlot
 from .waveformplot import PyDMWaveformPlot
 from .scatterplot import PyDMScatterPlot
+from .eventplot import PyDMEventPlot
 from .tab_bar_qtplugin import TabWidgetPlugin
 from .template_repeater import PyDMTemplateRepeater
 from .terminator import PyDMTerminator
@@ -91,6 +94,14 @@ PyDMScatterPlotPlugin = qtplugin_factory(PyDMScatterPlot,
                                              RulesExtension],
                                          icon=ifont.icon("project-diagram"))
 
+# Event Plot plugin
+PyDMEventPlotPlugin = qtplugin_factory(PyDMEventPlot,
+                                         group=WidgetCategory.PLOT,
+                                         extensions=[
+                                             EventCurveEditorExtension,
+                                             RulesExtension],
+                                         icon=ifont.icon("project-diagram"))
+
 # Byte plugin
 PyDMByteIndicatorPlugin = qtplugin_factory(PyDMByteIndicator,
                                            group=WidgetCategory.DISPLAY,
